@@ -656,7 +656,8 @@ class ComicDb():
 		elif comic[-13:] == "matinmaapallo":
 			realcomic = string.split( comic, 'matinmaapallo', 1)
 			linkname = realcomic[0]
-			link = "http://matin.maapallo.org/site.pl/selain/?c=" + linkname + "&i=" + str(number)
+			#link = "http://matin.maapallo.org/site.pl/selain/?c=" + linkname + "&i=" + str(number)
+			link = comics[comic]['link'] + str(number)
 			print "link: " + link
 			try:
 				f = urllib2.urlopen(link)
@@ -1004,7 +1005,7 @@ class ComicDb():
 				#print url
 				splt3 = string.split(s, '<h4>', 1)
 				splt4 = string.split(splt3[1], '</h4>', 1)
-				title = splt4[0]
+				title = splt4[0][-11:]
 				print title
 				filename = str(number) + ".gif"
 				irow = [comic,number,link,url,filename,title]
